@@ -6,11 +6,14 @@ from django.conf import settings
 
 DEFAULT_TWILL_PORT = 9876
 
+TWILL_PORT = getattr(settings, 'TWILL_WSGI_PORT', DEFAULT_TWILL_PORT)
+TWILL_HOST = '127.0.0.1'
+
+TWILL_HOME = '%s:%s' % (TWILL_HOST, TWILL_PORT)
 
 def setup():
     from django.core.servers.basehttp import AdminMediaHandler
     from django.core.handlers.wsgi import WSGIHandler
     app = AdminMediaHandler(WSGIHandler())
-    twill_port = getattr(settings, 'TWILL_WSGI_PORT', DEFAULT_TWILL_PORT)
-    add_wsgi_intercept("127.0.0.1", twill_port, lambda: app)
+    add_wsgi_intercept(TWILL_HOST, TWILL_PORT, lambda: app)
 
